@@ -35,7 +35,7 @@ logger = getLogger(__name__)
 class PluginCommands(Plugin):
     """ user backend elements management plugin """
 
-    def __init__(self, app, cfg_filenames=None):
+    def __init__(self, webui, plugin_dir, cfg_filenames=None):
         """
         User plugin
 
@@ -48,4 +48,4 @@ class PluginCommands(Plugin):
 
         self.pages = {}
 
-        super(PluginCommands, self).__init__(app, cfg_filenames)
+        super(PluginCommands, self).__init__(webui, plugin_dir, cfg_filenames)
