@@ -34,11 +34,8 @@ logger = getLogger(__name__)
 class PluginHistorys(Plugin):
     """ History plugin """
 
-    def __init__(self, app, cfg_filenames=None):
-        """
-        User plugin
-
-        Declare routes for adding, deleting a user
+    def __init__(self, webui, plugin_dir, cfg_filenames=None):
+        """History plugin
 
         Overload the default get route to declare filters.
         """
@@ -47,4 +44,4 @@ class PluginHistorys(Plugin):
 
         self.pages = {}
 
-        super(PluginHistorys, self).__init__(app, cfg_filenames)
+        super(PluginHistorys, self).__init__(webui, plugin_dir, cfg_filenames)
