@@ -34,7 +34,7 @@ logger = getLogger(__name__)
 class PluginServicesDependencies(Plugin):
     """ Services dependencies plugin """
 
-    def __init__(self, app, cfg_filenames=None):
+    def __init__(self, webui, plugin_dir, cfg_filenames=None):
         """
         User plugin
 
@@ -47,4 +47,4 @@ class PluginServicesDependencies(Plugin):
 
         self.pages = {}
 
-        super(PluginServicesDependencies, self).__init__(app, cfg_filenames)
+        super(PluginServicesDependencies, self).__init__(webui, plugin_dir, cfg_filenames)
