@@ -36,7 +36,6 @@ from logging import getLogger
 
 from bottle import request
 
-from alignak_webui import _
 from alignak_webui.objects.element_state import ElementState
 from alignak_webui.utils.helper import Helper
 from alignak_webui.objects.element import BackendElement
@@ -49,12 +48,13 @@ class Datatable(object):
 
     """jQuery  Datatable plugin interface for backend elements """
 
-    def __init__(self, object_type, datamgr, schema):
-        """
-        Create a new datatable:
+    def __init__(self, object_type, datamgr, plugin_table, templates=False):
+        """ Create a new datatable:
+
         - object_type: object type in the backend
         - backend: backend endpoint (http://127.0.0.1:5002)
-        - schema: table configuration as defined in the settings.cfg file of a plugin
+        - plugin_table: table configuration as defined in a plugin
+        - templates: templates table or objects table (False)
         """
         self.object_type = object_type
         self.datamgr = datamgr
@@ -70,8 +70,12 @@ class Datatable(object):
 
         self.title = ""
 
+        # data_model is the complete data model of the plugin
+        self.data_model = []
+        # table_columns only contains the columns displayed in the table view
         self.table_columns = []
         self.initial_sort = []
+        self.embedded = []
 
         self.visible = True
         self.printable = True
@@ -81,7 +85,7 @@ class Datatable(object):
         self.editable = True
         self.responsive = True
         self.recursive = False
-        self.commands = (object_type == 'host') or (object_type == 'service')
+        self.commands = object_type in ['host', 'service', 'user']
 
         self.css = "compact nowrap"
 
@@ -89,25 +93,28 @@ class Datatable(object):
         self.exportable = True
         self.printable = True
 
+        # Table concers a templated backend endpoint (host, service, user)
+        self.is_templated = False
+
         self.id_property = None
         self.name_property = None
         self.status_property = None
 
-        self.get_data_model(schema)
-
+        # Get table structure and description
+        self.templates = templates
         self.is_templated = False
-        for field in self.table_columns:
-            if field['data'] == '_is_template':
-                self.is_templated = True
-                self.records_total = self.backend.count(
-                    self.object_type, params={'where': {'_is_template': False}}
-                )
-                break
+        self.get_data_model(plugin_table)
+
+        # Templates management
+        if self.is_templated:
+            self.records_total = self.backend.count(self.object_type,
+                                                    params={
+                                                        'where': {'_is_template': self.templates}
+                                                    })
         else:
             self.records_total = self.backend.count(self.object_type)
 
-    def get_data_model(self, schema):
-
+    def get_data_model(self, plugin_table):
         """Get the data model for an element type
 
             If the data model specifies that the element is managed in the UI,
@@ -120,34 +127,37 @@ class Datatable(object):
                 of the linked object
                 - if the field contains 'allowed' values, format is set to 'select'
 
-
             Returns a dictionary containing:
             - element_type: element type
             - uid: unique identifier for the element type. Contains the field that is to be used as
                 a unique identifier field
             - page_title: title format string to be used for an element page
             - fields: list of dictionaries. One dictionary per each field mentioned as visible in
-                the ui in its schema. The dictionary contains all the fields defined in the 'ui'
-                property of the schema of the element.
+                the ui in its plugin_table.
 
-            :return: list of fields name/title
-        """
-
-        if not schema:
-            logger.error("get_data_model, missing schema")
-            return None
+            :return: list of fields name/title"""
+        # Current logged user skill level
+        user_level = self.datamgr.logged_in_user.skill_level
 
+        self.data_model = []
         self.table_columns = []
-        for field, model in schema.iteritems():
+        for field, model in plugin_table.iteritems():
+            logger.debug('get_data_model, field: %s, plugin_table: %s', field, model)
+
+            if 'skill_level' in model and model['skill_level'] > user_level:
+                logger.info("UI field has a greater skill level: %s.%s vs %s",
+                            field, model['skill_level'], user_level)
+                continue
+
             # Global table configuration?
             if field == '_table':
-                # logger.debug('get_data_model, table UI schema: %s', model)
-
                 self.id_property = model.get('id_property', '_id')
                 self.name_property = model.get('name_property', 'name')
                 self.status_property = model.get('status_property', 'status')
 
-                self.title = model['page_title']
+                self.items_title = model.get('page_title', _('Items table (%d items)'))
+                self.templates_title = model.get('template_page_title', self.items_title)
+
                 self.visible = model.get('visible', self.visible)
                 self.printable = model.get('printable', self.printable)
                 self.orderable = model.get('orderable', self.orderable)
@@ -157,12 +167,25 @@ class Datatable(object):
                 self.responsive = model.get('responsive', self.responsive)
                 self.recursive = model.get('recursive', self.recursive)
                 self.commands = model.get('commands', self.commands)
+                self.paginable = model.get('paginable', self.paginable)
                 self.css = model.get('css', "display nowrap")
 
                 self.initial_sort = model.get('initial_sort', [[0, 'desc']])
                 continue
 
-            # logger.debug("get_data_model, visible field: %s = %s", field, model)
+            if field == '_is_template':
+                self.is_templated = True
+
+            if self.templates:
+                self.title = self.templates_title
+            else:
+                self.title = self.items_title
+
+            # ignore this field if we display the templates and it is configured as ignored...
+            templates_included = model.get('templates_table', False)
+            if self.templates and not templates_included:
+                logger.debug('get_data_model, templates table filtered: %s', field)
+                continue
 
             # Get all the definitions made in the plugin configuration...
             ui_field = model
@@ -172,18 +195,17 @@ class Datatable(object):
                 'type': model.get('type', 'string'),
                 'content_type': model.get('content_type', model.get('type', 'string')),
                 'allowed': model.get('allowed', ''),
-                'defaultContent': model.get('default', ''),
+                'default': model.get('default', ''),
                 'required': model.get('required', False),
                 'empty': model.get('empty', False),
                 'unique': model.get('unique', False),
 
-                'regex': model.get('regex', True),
+                'regex_search': model.get('regex_search', True),
                 'title': model.get('title', field),
-                'hint': model.get('hint', ''),
+                'comment': model.get('comment', ''),
                 'format': model.get('format', ''),
                 'format_parameters': model.get('format_parameters', ''),
                 'visible': model.get('visible', True),
-                # 'visible': model.get('visible', not model.get('hidden', False)),
                 'hidden': model.get('hidden', False),
                 'orderable': model.get('orderable', True),
                 'editable': model.get('editable', True),
@@ -195,23 +217,33 @@ class Datatable(object):
             if model.get('hidden', False):
                 ui_field.update({'visible': True})
 
-            if model.get('type') in ['objectid', 'list'] and model.get('data_relation'):
+            if self.templates and templates_included:
+                ui_field.update({'visible': True})
+                ui_field.update({'hidden': False})
+
+            if model.get('type') in ['objectid', 'list'] and model.get('data_relation', None):
+                relation = model.get('data_relation')
+                logger.debug('get_data_model, object/list field: %s / %s',
+                             field, relation.get('resource', None))
                 ui_field.update(
-                    {'content_type': 'objectid:' + model.get('resource', 'unknown')}
-                )
+                    {'content_type': 'objectid:' + relation.get('resource', 'unknown')})
 
             # logger.debug("get_data_model, field: %s = %s", field, ui_field)
 
             # If not hidden, return field
+            # self.data_model.append(ui_field)
             if not model.get('hidden', False):
                 self.table_columns.append(ui_field)
-        return None
+
+                if ui_field['type'] == 'objectid' or \
+                        ui_field['content_type'].startswith('objectid'):
+                    self.embedded.append(ui_field['data'])
+
+        return self.data_model
 
     @staticmethod
     def get_language_strings():
-
         """Get DataTable language strings"""
-
         return {
             'decimal': _('.'),
             'thousands': _(','),
@@ -280,15 +312,11 @@ class Datatable(object):
             }
         }
 
-    #
-    # Data source
-    #
-    def table_data(self):
+    def table_data(self, plugin_table):
         # Because there are many locals needed :)
         # pylint: disable=too-many-locals
+        """Return elements data in json format as of Datatables SSP protocol
 
-        """
-        Return elements data in json format as of Datatables SSP protocol
         More info: https://datatables.net/manual/server-side
 
         Example URL::
@@ -356,13 +384,9 @@ class Datatable(object):
         - error (optional): Error message if an error occurs
             Not included if there is no error.
         """
-
         # Manage request parameters ...
-        logger.info("request data for table: %s", request.forms.get('object_type'))
-
-        for field in self.table_columns:
-            if field['data'] == '_is_template':
-                logger.warning("table_data, model: %s: %s", field['data'], field)
+        logger.info("request data for table: %s, templates: %s",
+                    request.forms.get('object_type'), self.templates)
 
         # Because of specific datatables parameters name (eg. columns[0] ...)
         # ... some parameters have been json.stringify on client side !
@@ -385,10 +409,8 @@ class Datatable(object):
 
         parameters['page'] = (first_row // rows_count) + 1
         parameters['max_results'] = rows_count
-        logger.debug(
-            "get %d rows from row #%d -> page: %d",
-            rows_count, first_row, parameters['page']
-        )
+        logger.debug("get %d rows from row #%d -> page: %d",
+                     rows_count, first_row, parameters['page'])
 
         # Columns ordering
         # order:[{"column":2,"dir":"desc"}]
@@ -411,17 +433,15 @@ class Datatable(object):
             logger.info("backend order request parameters: %s", parameters)
 
         # Individual column search parameter
-        searched_columns = []
+        s_columns = []
         if 'columns' in params and params['columns']:
             for column in params['columns']:
                 if 'searchable' not in column or 'search' not in column:  # pragma: no cover
                     continue
                 if 'value' not in column['search'] or not column['search']['value']:
                     continue
-                logger.debug(
-                    "search column '%s' for '%s'",
-                    column['data'], column['search']['value']
-                )
+                logger.debug("search column '%s' for '%s'",
+                             column['data'], column['search']['value'])
 
                 for field in self.table_columns:
                     if field['data'] != column['data']:
@@ -429,17 +449,17 @@ class Datatable(object):
 
                     # Some specific types...
                     if field['type'] == 'boolean':
-                        searched_columns.append(
+                        s_columns.append(
                             {column['data']: column['search']['value'] == 'true'}
                         )
                     elif field['type'] == 'integer':
-                        searched_columns.append(
+                        s_columns.append(
                             {column['data']: int(column['search']['value'])}
                         )
                     elif field['format'] == 'select':
                         values = column['search']['value'].split(',')
                         if len(values) > 1:
-                            searched_columns.append(
+                            s_columns.append(
                                 {
                                     column['data']: {
                                         "$in": values
@@ -447,14 +467,14 @@ class Datatable(object):
                                 }
                             )
                         else:
-                            searched_columns.append(
+                            s_columns.append(
                                 {column['data']: values[0]}
                             )
                     # ... the other fields :)
                     else:
                         # Do not care about 'smart' and 'caseInsensitive' boolean parameters ...
                         if column['search']['regex']:
-                            searched_columns.append(
+                            s_columns.append(
                                 {
                                     column['data']: {
                                         "$regex": ".*" + column['search']['value'] + ".*"
@@ -462,80 +482,79 @@ class Datatable(object):
                                 }
                             )
                         else:
-                            searched_columns.append(
+                            s_columns.append(
                                 {column['data']: column['search']['value']}
                             )
                     break
 
-            logger.info("backend search individual columns parameters: %s", searched_columns)
+            logger.info("backend search individual columns parameters: %s", s_columns)
 
         # Global search parameter
         # search:{"value":"test","regex":false}
-        searched_global = []
+        s_global = {}
         # pylint: disable=too-many-nested-blocks
         # Will be too complex else ...
         if 'search' in params and 'columns' in params and params['search']:
+            # params['search'] contains something like: {u'regex': False, u'value': u'name:pi1'}
+            # global regex is always ignored ... in favor of the column declared regex
+            logger.info("global search requested: %s ", params['search'])
             if 'value' in params['search'] and params['search']['value']:
+                # There is something to search for...
                 logger.debug("search requested, value: %s ", params['search']['value'])
-                for column in params['columns']:
-                    if 'searchable' in column and column['searchable']:
-                        logger.debug(
-                            "search global '%s' for '%s'",
-                            column['data'], params['search']['value']
-                        )
-                        if 'regex' in params['search']:
-                            if params['search']['regex']:
-                                searched_global.append(
-                                    {
-                                        column['data']: {
-                                            "$regex": ".*" + params['search']['value'] + ".*"
-                                        }
-                                    }
-                                )
-                            else:
-                                searched_global.append(
-                                    {column['data']: params['search']['value']}
-                                )
 
-            logger.info("backend search global parameters: %s", searched_global)
+                # New strategy: decode search patterns...
+                search = Helper.decode_search(params['search']['value'], plugin_table)
+                logger.info("decoded search pattern: %s", search)
 
-        if searched_columns and searched_global:
-            parameters['where'] = {"$and": [
-                {"$and": searched_columns},
-                {"$or": searched_global}
-            ]}
-        if searched_columns:
-            parameters['where'] = {"$and": searched_columns}
-        if searched_global:
-            parameters['where'] = {"$or": searched_global}
+                # Old strategy: search for the value in all the searchable columns...
+                # if not search:
+                #     logger.info("applying datatable search pattern...")
+                #     for column in params['columns']:
+                #         if not column['searchable']:
+                #             continue
+                #         logger.debug("search global '%s' for '%s'",
+                #                      column['data'], params['search']['value'])
+                #         if 'regex' in params['search']:
+                #             if params['search']['regex']:
+                #                 s_global.update(
+                #                     {column['data']: {
+                #                         "$regex": ".*" + params['search']['value'] + ".*"}})
+                #             else:
+                #                 s_global.update({column['data']: params['search']['value']})
+                s_global = search
+
+            logger.info("backend search global parameters: %s", s_global)
+
+        # Specific hack to filter the log check results that are not dated!
+        if self.object_type == 'logcheckresult':
+            s_columns.append({"last_check": {"$ne": 0}})
+
+        if s_columns and s_global:
+            parameters['where'] = {"$and": [{"$and": s_columns}, s_global]}
+        elif s_columns:
+            parameters['where'] = {"$and": s_columns}
+        elif s_global:
+            parameters['where'] = s_global
 
         # Embed linked resources / manage templated resources
         parameters['embedded'] = {}
-        for field in self.table_columns:
-            # logger.debug("field: %s", field['data'])
-            if field['type'] == 'objectid' or field['content_type'] == 'objectid':
-                parameters['embedded'].update({field['data']: 1})
+        for field in self.embedded:
+            parameters['embedded'].update({field: 1})
 
         logger.debug("backend embedded parameters: %s", parameters['embedded'])
 
         # Count total elements excluding templates if necessary
-        self.is_templated = False
-        for field in self.table_columns:
-            if field['data'] == '_is_template':
-                self.is_templated = True
-                self.records_total = self.backend.count(
-                    self.object_type, params={'where': {'_is_template': False}}
-                )
-                break
+        if self.is_templated:
+            self.records_total = self.backend.count(
+                self.object_type, params={'where': {'_is_template': self.templates}}
+            )
+            if 'where' in parameters:
+                parameters['where'].update({'_is_template': self.templates})
+            else:
+                parameters['where'] = {'_is_template': self.templates}
         else:
             self.records_total = self.backend.count(self.object_type)
 
-        if self.is_templated:
-            if 'where' in parameters:
-                parameters['where'].update({'_is_template': False})
-            else:
-                parameters['where'] = {'_is_template': False}
-
         # Request objects from the backend ...
         logger.info("table data get parameters: %s", parameters)
         items = self.backend.get(self.object_type, params=parameters)
@@ -554,7 +573,7 @@ class Datatable(object):
         # Create an object ...
         object_class = [kc for kc in self.datamgr.known_classes
                         if kc.get_type() == self.object_type]
-        if not object_class:
+        if not object_class:  # pragma: no cover, should never happen!
             logger.warning("datatable, unknown object type: %s", self.object_type)
             # Empty response
             return json.dumps({
@@ -565,88 +584,114 @@ class Datatable(object):
                 "data": []
             })
 
+        # Update table inner properties with the object class defined properties
         object_class = object_class[0]
-        bo_object = object_class()
 
-        # Update inner properties
         self.id_property = '_id'
-        if hasattr(bo_object.__class__, 'id_property'):
-            self.id_property = bo_object.__class__.id_property
+        if hasattr(object_class, 'id_property'):
+            self.id_property = object_class.id_property
         self.name_property = 'name'
-        if hasattr(bo_object.__class__, 'name_property'):
-            self.name_property = bo_object.__class__.name_property
+        if hasattr(object_class, 'name_property'):
+            self.name_property = object_class.name_property
         self.status_property = 'status'
-        if hasattr(bo_object.__class__, 'status_property'):
-            self.status_property = bo_object.__class__.status_property
+        if hasattr(object_class, 'status_property'):
+            self.status_property = object_class.status_property
+        logger.debug("datatable, object type: '%s' and properties: %s / %s / %s",
+                     object_class, self.id_property, self.name_property, self.status_property)
 
-        # Change item content ...
+        # Change item content...
         rows = []
+        # Total number of filtered records
+        self.records_filtered = self.records_total
         for item in items:
             bo_object = object_class(item)
             logger.debug("table data object: %s", bo_object)
+            # This is an awful hack that allows to update the objects filtered for a table.
+            # Two main interests:
+            # - update the backend because some massive modifications are necessary for testing
+            # - prepare a massive update feature in the Web UI :)
+            # -----
+            # if self.is_templated and self.templates and self.object_type == 'service':
+            #     logger.warning("service template: %s for host: %s",
+            #                    bo_object.name, bo_object['host'])
+            #     if bo_object['host'].name.startswith('fdj'):
+            #         logger.info("To be updated...")
+            #         data = {
+            #             "check_freshness": True,
+            #             "freshness_threshold": 86400,
+            #             "passive_checks_enabled": True,
+            #             "active_checks_enabled": False
+            #         }
+            #         result = self.datamgr.update_object(element=bo_object, data=data)
+            #         if result is True:
+            #             logger.info("updated.")
+            #         else:
+            #             logger.error("update failed!")
+            # -----
+
+            # Each item contains the total number of records matching the search filter
+            self.records_filtered = item['_total']
 
             row = {}
             row['DT_RowData'] = {}
             row['_id'] = bo_object.id
             for field in self.table_columns:
-                if field['hidden']:
-                    logger.critical("field %s is not declared as visible.", field['data'])
-                    continue
-
                 # Specific fields
                 if field['data'] == self.name_property:
-                    # item[field] = bo_object.get_html_link(prefix=request.params.get('links'))
+                    # Create a link to navigate to the item page
                     row[self.name_property] = bo_object.html_link
-                    row['DT_RowData'].update(
-                        {"object_%s" % self.object_type: bo_object.name}
-                    )
+                    # Store the item name in a specific field of the row.
+                    # The value will be retrieved by the table actions (ack, recheck, ...)
+                    row['DT_RowData'].update({"object_%s" % self.object_type: bo_object.name})
                     continue
 
                 if field['data'] == self.status_property:
-                    row[self.status_property] = bo_object.get_html_state(text=None)
-                    row['DT_RowClass'] = "table-row-%s" % (bo_object.status.lower())
+                    # Replace the text status with the specific item HTML state
+                    row[self.status_property] = bo_object.get_html_state(text=None,
+                                                                         title=bo_object.status)
+                    # Use the item status to specify the table row class
+                    # row['DT_RowClass'] = "table-row-%s" % (bo_object.status.lower())
                     continue
 
-                if field['data'] == 'overall_state':
-                    # Get elements from the data manager
-                    f_get_overall_state = getattr(
-                        self.datamgr, 'get_%s_overall_state' % self.object_type
-                    )
+                if field['data'] in ['_overall_state_id', 'overall_state', 'overall_status']:
+                    # Get the item overall state from the data manager
+                    f_get_overall_state = getattr(self.datamgr,
+                                                  'get_%s_overall_state' % self.object_type)
                     if f_get_overall_state:
                         (dummy, overall_status) = f_get_overall_state(bo_object)
 
                         # Get element state configuration
                         row[field['data']] = ElementState().get_html_state(
                             self.object_type, bo_object,
-                            text=None, use_status=overall_status
+                            text=None,
+                            title=bo_object.overall_state_to_title[bo_object.overall_state],
+                            use_status=overall_status
                         )
+                        # Use the item overall state to specify the table row class
                         row['DT_RowClass'] = "table-row-%s" % (overall_status)
-                    else:
+                    else:  # pragma: no cover, should never happen!
+                        logger.warning("Missing get_overall_state method for: %s", self.object_type)
                         row[field['data']] = 'XxX'
                     continue
 
-                if field['data'] == "alias":
-                    row[field['data']] = bo_object.alias
-                    continue
-
-                if field['data'] == "notes":
-                    row[field['data']] = bo_object.notes
-                    continue
-
-                if field['data'] == "business_impact":
+                if "business_impact" in field['data']:
+                    # Replace the BI count with the specific item HTML formatting
                     row[field['data']] = Helper.get_html_business_impact(bo_object.business_impact)
                     continue
 
                 # Specific fields type
-                if field['type'] == 'datetime':
+                if field['type'] == 'datetime' or field['format'] == 'datetime':
+                    # Replace the timestamp with the formatted date
                     row[field['data']] = bo_object.get_date(bo_object[field['data']])
                     continue
 
                 if field['type'] == 'boolean':
+                    # Replace the boolean vaue with the specific item HTML formatting
                     row[field['data']] = Helper.get_on_off(bo_object[field['data']])
                     continue
 
                 if field['type'] == 'list':
+                    # Replace the list with the specific list HTML formatting
                     if hasattr(bo_object, field['data']):
                         row[field['data']] = Helper.get_html_item_list(
                             bo_object.id, field['data'],
@@ -657,6 +702,7 @@ class Datatable(object):
                     continue
 
                 if field['type'] == 'dict':
+                    # Replace the dictionary with the specific dict HTML formatting
                     row[field['data']] = Helper.get_html_item_list(
                         bo_object.id, field['data'],
                         getattr(bo_object, field['data']), title=field['title']
@@ -668,40 +714,32 @@ class Datatable(object):
                         row[field['data']] = bo_object[field['data']].get_html_link(
                             prefix=request.params.get('links')
                         )
-                        row['DT_RowData'].update(
-                            {"object_%s" % field['data']: bo_object[field['data']].name}
-                        )
+                        # row['DT_RowData'].update({
+                        #     "object_%s" % field['data']: bo_object[field['data']].name
+                        # })
                     else:
-                        logger.debug(
-                            "Table field object is not an object: %s, %s = %s",
-                            bo_object.name, field['data'], getattr(bo_object, field['data'])
-                        )
+                        logger.warning("Table field is supposed to be an object: %s, %s = %s",
+                                       bo_object.name, field['data'],
+                                       getattr(bo_object, field['data']))
                         row[field['data']] = getattr(bo_object, field['data'])
                         if row[field['data']] == field['resource']:
                             row[field['data']] = '...'
                     continue
 
+                # For ny non-specific fields, send the firled value to the table
                 row[field['data']] = getattr(bo_object, field['data'])
             logger.debug("table data row: %s", row)
 
             # logger.debug("Table row: %s", row)
             rows.append(row)
 
-        # Total number of filtered records
-        self.records_filtered = self.records_total
-        if 'where' in parameters and parameters['where'] != {}:
-            logger.debug("update filtered records: %s", parameters['where'])
-            self.records_filtered = len(items)
-        logger.info(
-            "filtered records: %d out of total: %d", self.records_filtered, self.records_total
-        )
+        logger.debug("filtered records: %d out of total: %d",
+                     self.records_filtered, self.records_total)
 
-        # Prepare response
-        rsp = {
-            # draw is the request number ...
+        # Send response
+        return json.dumps({
             "draw": int(params.get('draw', '0')),
             "recordsTotal": self.records_total,
             "recordsFiltered": self.records_filtered,
             "data": rows
-        }
-        return json.dumps(rsp)
+        })
