@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015:
+# Copyright (c) 2015-2017:
 #   Frederic Mohier, frederic.mohier@gmail.com
 #
 # This file is part of (WebUI).
@@ -28,14 +28,13 @@ import subprocess
 import time
 
 import unittest2
-from nose.tools import *
 
-# Test environment variables
-os.environ['TEST_WEBUI'] = '1'
-os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'] = \
-    os.path.join(os.path.abspath(os.path.dirname(__file__)), 'settings.cfg')
-print("Configuration file: %s" % os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'])
-# To load application configuration used by the objects
+# Set test mode ...
+os.environ['ALIGNAK_WEBUI_TEST'] = '1'
+os.environ['ALIGNAK_WEBUI_DEBUG'] = '1'
+os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'] = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'settings.cfg')
+print("Configuration file", os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'])
+
 import alignak_webui.app
 
 from alignak_webui.objects.element import BackendElement
@@ -47,7 +46,7 @@ from alignak_webui.objects.item_service import Service
 from alignak_webui.objects.item_timeperiod import TimePeriod
 from alignak_webui.objects.item_hostgroup import HostGroup
 from alignak_webui.objects.item_servicegroup import ServiceGroup
-from alignak_webui.objects.datamanager import DataManager
+from alignak_webui.backend.datamanager import DataManager
 
 from logging import getLogger, DEBUG, INFO, WARNING
 
@@ -62,13 +61,13 @@ backend_process = None
 backend_address = "http://127.0.0.1:5000/"
 datamgr = None
 
-COUNT_KNOWN_CLASSES = 19
+COUNT_KNOWN_CLASSES = 26
 
 
 def setup_module(module):
     # Set test mode for applications backend
     os.environ['TEST_ALIGNAK_BACKEND'] = '1'
-    os.environ['ALIGNAK_BACKEND_MONGO_DBNAME'] = 'alignak-backend-test'
+    os.environ['ALIGNAK_BACKEND_MONGO_DBNAME'] = 'alignak-webui-tests'
 
     # Delete used mongo DBs
     exit_code = subprocess.call(
@@ -94,7 +93,7 @@ def setup_module(module):
 
     print("Feeding Alignak backend... %s" % test_dir)
     exit_code = subprocess.call(
-        shlex.split('alignak-backend-import --delete %s/cfg/default/_main.cfg' % test_dir),
+        shlex.split('alignak-backend-import --delete %s/cfg/alignak-demo/alignak-backend-import.cfg' % test_dir),
         stdout=fnull
     )
     assert exit_code == 0
@@ -116,7 +115,7 @@ class TestCreation(unittest2.TestCase):
         print('------------------------------')
         print('test creation')
 
-        datamanager = DataManager()
+        datamanager = DataManager(alignak_webui.app.app)
         assert datamanager.backend
         assert datamanager.loaded == False
         assert datamanager.logged_in_user is None
@@ -134,13 +133,13 @@ class TestCreation(unittest2.TestCase):
         print('DM logging bad password')
         assert not datamanager.user_login('admin', 'fake')
         print(datamanager.connection_message)
-        assert datamanager.connection_message == 'Backend connection refused...'
+        assert datamanager.connection_message == 'Access denied! Check your username and password.'
         print(datamanager.logged_in_user)
         assert not datamanager.logged_in_user
 
         # Create new datamanager - do not use default backend address
         print('DM initialization')
-        datamanager = DataManager(backend_endpoint=backend_address)
+        datamanager = DataManager(alignak_webui.app.app)
         assert datamanager.backend
         assert datamanager.loaded == False
         assert datamanager.logged_in_user is None
@@ -156,14 +155,14 @@ class TestCreation(unittest2.TestCase):
         print('DM logging bad password')
         assert not datamanager.user_login('admin', 'fake')
         print(datamanager.connection_message)
-        assert datamanager.connection_message == 'Backend connection refused...'
+        assert datamanager.connection_message == 'Access denied! Check your username and password.'
         print(datamanager.logged_in_user)
         assert not datamanager.logged_in_user
 
         # User login but do not load yet
         print('DM login ok')
         assert datamanager.user_login('admin', 'admin', load=False)
-        assert datamanager.connection_message == 'Connection successful'
+        assert datamanager.connection_message == 'Access granted'
         print("Logged user: %s" % datamanager.logged_in_user)
         assert datamanager.logged_in_user
         assert datamanager.logged_in_user is not None
@@ -196,7 +195,7 @@ class TestCreation(unittest2.TestCase):
         print(datamanager.logged_in_user.token)
         user_token = datamanager.logged_in_user.token
         assert datamanager.user_login(user_token)
-        assert datamanager.connection_message == 'Connection successful'
+        assert datamanager.connection_message == 'Access granted'
 
         assert datamanager.logged_in_user
         assert datamanager.logged_in_user is not None
@@ -207,12 +206,9 @@ class TestCreation(unittest2.TestCase):
 
 class TestLoadCreate(unittest2.TestCase):
     def setUp(self):
-        self.dmg = DataManager(backend_endpoint=backend_address)
+        self.dmg = DataManager(alignak_webui.app.app)
         print('Data manager', self.dmg)
 
-    def tearDown(self):
-        print("")
-
     def test_3_1_load(self):
         """ Datamanager load """
         print('test load as admin')
@@ -270,7 +266,7 @@ class TestLoadCreate(unittest2.TestCase):
 
 class TestNotAdmin(unittest2.TestCase):
     def setUp(self):
-        self.dmg = DataManager(backend_endpoint=backend_address)
+        self.dmg = DataManager(alignak_webui.app.app)
         print('Data manager', self.dmg)
 
     @unittest2.skip("Skipped because creating a new user do not allow him to get its own data (timeperiod get is 404)!")
@@ -357,6 +353,9 @@ class TestNotAdmin(unittest2.TestCase):
         result = self.dmg.load()
         print("Result:", result)
         print("Objects count:", self.dmg.get_objects_count())
+        print("Objects count:", self.dmg.get_objects_count('host'))
+        print("Objects count:", self.dmg.get_objects_count('service'))
+        print("Objects count (log):", self.dmg.get_objects_count(log=True))
         # assert result == 0                          # Only the newly created user, so no new objects loaded
         # assert self.dmg.get_objects_count() == 1    # not_admin user
 
@@ -364,6 +363,9 @@ class TestNotAdmin(unittest2.TestCase):
         result = self.dmg.load(reset=True)
         print("Result:", result)
         print("Objects count:", self.dmg.get_objects_count())
+        print("Objects count:", self.dmg.get_objects_count('host'))
+        print("Objects count:", self.dmg.get_objects_count('service'))
+        print("Objects count (log):", self.dmg.get_objects_count(log=True))
         # assert result == 3                          # not_admin user + test_service + relation
         # assert self.dmg.get_objects_count() == 3    # not_admin user + test_service + relation
 
@@ -427,7 +429,7 @@ class TestNotAdmin(unittest2.TestCase):
 
 class TestBasic(unittest2.TestCase):
     def setUp(self):
-        self.dmg = DataManager(backend_endpoint=backend_address)
+        self.dmg = DataManager(alignak_webui.app.app)
         print('Data manager', self.dmg)
 
         # Initialize and load ... no reset
@@ -451,7 +453,7 @@ class TestBasic(unittest2.TestCase):
             print("Got: ", item)
             assert item.id
             item.get_html_state()
-        assert len(items) == 5
+        assert len(items) == 4
 
         # Get commands
         items = self.dmg.get_commands()
@@ -467,7 +469,7 @@ class TestBasic(unittest2.TestCase):
             print("Got: ", item)
             assert item.id
             item.get_html_state()
-        assert len(items) == 4
+        assert len(items) == 5
 
     def test_5_1_get_linked(self):
         """ Datamanager objects get - linked elements """
@@ -502,7 +504,7 @@ class TestBasic(unittest2.TestCase):
             assert item.id
             if item.level != 0:
                 assert isinstance(item._parent, HostGroup) # Must be an object
-        assert len(items) == 9
+        assert len(items) == 12
 
         # Get servicegroups
         items = self.dmg.get_servicegroups()
@@ -511,7 +513,7 @@ class TestBasic(unittest2.TestCase):
             assert item.id
             if item.level != 0:
                 assert isinstance(item._parent, ServiceGroup) # Must be an object
-        assert len(items) == 6
+        assert len(items) == 10
 
         # Get usergroups
         items = self.dmg.get_usergroups()
@@ -520,17 +522,19 @@ class TestBasic(unittest2.TestCase):
             assert item.id
             if item.level != 0:
                 assert isinstance(item._parent, UserGroup) # Must be an object
-        assert len(items) == 3
+        assert len(items) == 7
 
     def test_5_3_livesynthesis(self):
         """ Datamanager objects get - livesynthesis """
         print('test livesynthesis')
 
         self.maxDiff = None
+
+        # Get livesynthesis - user logged-in realm and its sub-realms
         expected_ls = {
             '_id': self.dmg.my_ls['_id'],
             'hosts_synthesis': {
-                'nb_elts': 13,
+                'nb_elts': 7,
                 'business_impact': 0,
 
                 'warning_threshold': 2.0, 'global_warning_threshold': 2.0,
@@ -540,17 +544,16 @@ class TestBasic(unittest2.TestCase):
                 'nb_up_hard': 0, 'nb_up_soft': 0,
                 'nb_down': 0, 'pct_down': 0.0,
                 'nb_down_hard': 0, 'nb_down_soft': 0,
-                'nb_unreachable': 13, 'pct_unreachable': 100.0,
-                'nb_unreachable_hard': 13, 'nb_unreachable_soft': 0,
+                'nb_unreachable': 7, 'pct_unreachable': 100.0,
+                'nb_unreachable_hard': 7, 'nb_unreachable_soft': 0,
 
-                'nb_problems': 13, 'pct_problems': 100.0,
+                'nb_problems': 7, 'pct_problems': 100.0,
                 'nb_flapping': 0, 'pct_flapping': 0.0,
                 'nb_acknowledged': 0, 'pct_acknowledged': 0.0,
                 'nb_in_downtime': 0, 'pct_in_downtime': 0.0,
             },
             'services_synthesis': {
-                # 'nb_elts': 76, Travis says 74 whereas it is 76 !
-                'nb_elts': 74,
+                'nb_elts': 151,
                 'business_impact': 0,
 
                 'warning_threshold': 2.0, 'global_warning_threshold': 2.0,
@@ -562,11 +565,8 @@ class TestBasic(unittest2.TestCase):
                 'nb_warning_hard': 0, 'nb_warning_soft': 0,
                 'nb_critical': 0, 'pct_critical': 0.0,
                 'nb_critical_hard': 0, 'nb_critical_soft': 0,
-                'nb_unknown': 74, 'pct_unknown': 100.0,
-                'nb_unknown_hard': 74, 'nb_unknown_soft': 0,
-                # Travis says 74 whereas it is 76 !
-                # 'nb_unknown': 76, 'pct_unknown': 100.0,
-                # 'nb_unknown_hard': 76, 'nb_unknown_soft': 0,
+                'nb_unknown': 151, 'pct_unknown': 100.0,
+                'nb_unknown_hard': 151, 'nb_unknown_soft': 0,
                 'nb_unreachable': 0, 'pct_unreachable': 0.0,
                 'nb_unreachable_hard': 0, 'nb_unreachable_soft': 0,
 
@@ -576,10 +576,58 @@ class TestBasic(unittest2.TestCase):
                 'nb_in_downtime': 0, 'pct_in_downtime': 0.0
             }
         }
+        got_ls = self.dmg.get_livesynthesis({'concatenation': '1',
+                                             'where': {'_realm': self.dmg.my_realm.id}})
+        assert got_ls['hosts_synthesis'] == expected_ls['hosts_synthesis']
+        assert got_ls['services_synthesis'] == expected_ls['services_synthesis']
 
-        # Get livesynthesis
+        # Get livesynthesis - user logged-in realm and no sub realms
+        expected_ls = {
+            '_id': self.dmg.my_ls['_id'],
+            'hosts_synthesis': {
+                'nb_elts': 7,
+                'business_impact': 0,
+
+                'warning_threshold': 2.0, 'global_warning_threshold': 2.0,
+                'critical_threshold': 5.0, 'global_critical_threshold': 5.0,
+
+                'nb_up': 0, 'pct_up': 0.0,
+                'nb_up_hard': 0, 'nb_up_soft': 0,
+                'nb_down': 0, 'pct_down': 0.0,
+                'nb_down_hard': 0, 'nb_down_soft': 0,
+                'nb_unreachable': 7, 'pct_unreachable': 100.0,
+                'nb_unreachable_hard': 7, 'nb_unreachable_soft': 0,
+
+                'nb_problems': 7, 'pct_problems': 100.0,
+                'nb_flapping': 0, 'pct_flapping': 0.0,
+                'nb_acknowledged': 0, 'pct_acknowledged': 0.0,
+                'nb_in_downtime': 0, 'pct_in_downtime': 0.0,
+            },
+            'services_synthesis': {
+                'nb_elts': 151,
+                'business_impact': 0,
+
+                'warning_threshold': 2.0, 'global_warning_threshold': 2.0,
+                'critical_threshold': 5.0, 'global_critical_threshold': 5.0,
+
+                'nb_ok': 0, 'pct_ok': 0.0,
+                'nb_ok_hard': 0, 'nb_ok_soft': 0,
+                'nb_warning': 0, 'pct_warning': 0.0,
+                'nb_warning_hard': 0, 'nb_warning_soft': 0,
+                'nb_critical': 0, 'pct_critical': 0.0,
+                'nb_critical_hard': 0, 'nb_critical_soft': 0,
+                'nb_unknown': 151, 'pct_unknown': 100.0,
+                'nb_unknown_hard': 151, 'nb_unknown_soft': 0,
+                'nb_unreachable': 0, 'pct_unreachable': 0.0,
+                'nb_unreachable_hard': 0, 'nb_unreachable_soft': 0,
+
+                'nb_problems': 0, 'pct_problems': 0.0,
+                'nb_flapping': 0, 'pct_flapping': 0.0,
+                'nb_acknowledged': 0, 'pct_acknowledged': 0.0,
+                'nb_in_downtime': 0, 'pct_in_downtime': 0.0
+            }
+        }
         got_ls = self.dmg.get_livesynthesis(self.dmg.my_ls['_id'])
-        print(got_ls)
         assert got_ls['hosts_synthesis'] == expected_ls['hosts_synthesis']
         assert got_ls['services_synthesis'] == expected_ls['services_synthesis']
 
@@ -587,7 +635,7 @@ class TestBasic(unittest2.TestCase):
 class TestRelations(unittest2.TestCase):
     def setUp(self):
         print("setting up ...")
-        self.dmg = DataManager(backend_endpoint=backend_address)
+        self.dmg = DataManager(alignak_webui.app.app)
         print('Data manager', self.dmg)
 
         # Initialize and do not load
@@ -609,7 +657,7 @@ class TestRelations(unittest2.TestCase):
         self.dmg.get_timeperiod({'where': {'name': '24x7'}})
 
         # Get host
-        host = self.dmg.get_host({'where': {'name': 'webui'}})
+        host = self.dmg.get_host({'where': {'name': 'localhost'}})
 
         print(host.__dict__)
         print(host.check_period)
@@ -627,7 +675,7 @@ class TestRelations(unittest2.TestCase):
         self.dmg.get_timeperiod({'where': {'name': '24x7'}})
 
         # Get host
-        host = self.dmg.get_host({'where': {'name': 'webui'}})
+        host = self.dmg.get_host({'where': {'name': 'localhost'}})
         print("Host: ", host.__dict__)
 
         # Get services of this host
@@ -638,7 +686,7 @@ class TestRelations(unittest2.TestCase):
 class TestHosts(unittest2.TestCase):
     def setUp(self):
         print("setting up ...")
-        self.dmg = DataManager(backend_endpoint=backend_address)
+        self.dmg = DataManager(alignak_webui.app.app)
         print('Data manager', self.dmg)
 
         # Initialize and do not load
@@ -682,38 +730,41 @@ class TestHosts(unittest2.TestCase):
 
         # Get all hosts templates
         hosts = self.dmg.get_hosts(template=True)
-        assert 30 == len(hosts)
+        assert 28 == len(hosts)
         print("---")
         for host in hosts:
             print("Got host template: %s" % host)
 
         # Get one host
-        hosts = self.dmg.get_hosts({'where': {'name': 'webui'}})
+        hosts = self.dmg.get_hosts({'where': {'name': 'alignak_glpi'}})
         assert 1 == len(hosts)
         print("---")
         for host in hosts:
             print("Got host: %s" % host)
-        assert hosts[0].name == 'webui'
+        assert hosts[0].name == 'alignak_glpi'
 
         # Get one host
-        host = self.dmg.get_host({'where': {'name': 'webui'}})
-        assert host.name == 'webui'
+        host = self.dmg.get_host({'where': {'name': 'alignak_glpi'}})
+        assert host.name == 'alignak_glpi'
 
         # Get one host
         host = self.dmg.get_host(host._id)
-        assert host.name == 'webui'
+        assert host.name == 'alignak_glpi'
         assert host.status == 'UNREACHABLE'
 
         # Get host services
-        services = self.dmg.get_host_services({'where': {'name': 'webui'}})
+        services = self.dmg.get_host_services({'where': {'name': 'unknown'}})
+        assert services == -1
+
+        services = self.dmg.get_host_services({'where': {'name': 'alignak_glpi'}})
         print("---")
+        service_name = ''
         for service in services:
             print("Got service: %s" % service)
+            service_name = service['name']
         assert len(services) > 1
+        services = self.dmg.get_host_services({'where': {'name': 'alignak_glpi'}}, search={'where': {'name': service_name}})
         services = self.dmg.get_host_services(host)
-        print("---")
-        for service in services:
-            print("Got service: %s" % service)
         assert len(services) > 1
 
         # Get host overall state
@@ -733,7 +784,7 @@ class TestHosts(unittest2.TestCase):
         self.dmg.get_timeperiod({'where': {'name': '24x7'}})
 
         # Get host
-        host = self.dmg.get_host({'where': {'name': 'webui'}})
+        host = self.dmg.get_host({'where': {'name': 'localhost'}})
 
         print(host.__dict__)
         print(host.check_period)
