@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015:
+# Copyright (c) 2015-2017:
 #   Frederic Mohier, frederic.mohier@gmail.com
 #
 # This file is part of (WebUI).
@@ -27,7 +27,15 @@ import time
 from calendar import timegm
 from datetime import datetime
 import unittest2
-from nose.tools import *
+import pytest
+
+# Set test mode ... application is tested in production mode!
+os.environ['ALIGNAK_WEBUI_DEBUG'] = '1'
+os.environ['ALIGNAK_WEBUI_TEST'] = '1'
+os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'] = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'settings.cfg')
+print("Configuration file", os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'])
+
+import alignak_webui.app
 
 from alignak_webui import get_app_config, set_app_config
 from alignak_webui.objects.element import BackendElement
@@ -44,15 +52,6 @@ loggerDm = logging.getLogger('alignak_webui.objects.backend')
 loggerDm.setLevel(logging.DEBUG)
 
 
-def setup_module(module):
-    # Get configuration from only one file ...
-    print ("read configuration")
-    cfg = Settings(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'settings.cfg'))
-    found_cfg_files = cfg.read('Alignak-WebUI')
-    assert found_cfg_files
-    set_app_config(cfg)
-
-
 class TestClassElements(unittest2.TestCase):
     def test_class(self):
         """ Items - class variables """
@@ -60,11 +59,9 @@ class TestClassElements(unittest2.TestCase):
 
         # Create basic object
         # Bad parameters
-        with assert_raises(ValueError) as cm:
+        with pytest.raises(ValueError) as excinfo:
             item = BackendElement(1)
-        ex = cm.exception
-        print(ex)
-        assert str(ex) == "item.__new__: object parameters must be a dictionary!"
+        assert str(excinfo.value) == "item.__new__: object parameters must be a dictionary!"
 
         # Declaration without any parameter is allowed
         item = BackendElement()
@@ -256,8 +253,9 @@ class TestElementStates(unittest2.TestCase):
         print("Items states", items_states.states)
 
         for s in self.config:
+            print(s)
             s = s.split('.')
-            if s[0] not in ['items'] and len(s) > 1:
+            if s[0] not in ['items', 'bottle'] and len(s) > 1:
                 assert s[1] not in items_states.object_types_states
                 assert s[1] not in items_states.default_states
                 assert s[1] not in items_states.states
@@ -424,7 +422,7 @@ class TestElementStates(unittest2.TestCase):
                                                  extra='test')
         print(item_state)
         assert item_state == \
-                         '''<div class="item-state item_user " style="display: inline; font-size:0.9em;" data-item-id="%s" data-item-name="anonymous" data-item-type="user" data-item-state="" title="test"><span class="fa-stack " style="opacity: 0.5"><i class="fa fa-circle fa-stack-2x item_user"></i><i class="fa fa-user fa-stack-1x fa-inverse"></i></span><span></span></div>''' % elt.id
+                         '''<div class="item-state item_user " style="display: inline; font-size:0.9em;" data-item-id="%s" data-item-name="anonymous" data-item-type="user" data-item-state="" title="testtest"><span class="fa-stack " ><i class="fa fa-circle fa-stack-2x item_user"></i><i class="fa fa-user fa-stack-1x fa-inverse"></i></span><span></span></div>''' % elt.id
 
 
 class TestItems(unittest2.TestCase):
@@ -460,6 +458,7 @@ class TestItems(unittest2.TestCase):
         assert item2.foo_int == 1
         assert item.name == 'anonymous'
         assert item.alias == 'anonymous'
+        assert item.json_alias == 'anonymous'
         assert item.notes == ''
 
         # Same objects!
@@ -601,6 +600,68 @@ class TestItems(unittest2.TestCase):
         assert item.notes == 'Item notes'
         assert item.status == 'unknown'
 
+        # Alias containing specific character
+        now = datetime.now()
+        parameters = {
+            'alias': 'Item "alias"',
+            'notes': 'Item notes',
+            'foo': 'bar', 'foo_int': 1,
+            'foo_date': '2016-04-01 10:58:13',
+            'now_date': now,
+            'dict_param': {
+                'param1': 1,
+                'param2': '2'
+            }
+        }
+        item = BackendElement(parameters, date_format='%Y-%m-%d %H:%M:%S')
+        print(item.__dict__)
+        assert item._id == 'item_4'  # New object
+        assert item.foo == 'bar'
+        assert item.foo_int == 1
+        assert item.foo_date == 1459508293
+        assert item.now_date == timegm(now.timetuple())
+        assert item.dict_param
+        print(item.dict_param)
+        assert item.dict_param['param1'] == 1
+        assert item.dict_param['param2'] == '2'
+
+        assert item.name == 'anonymous'
+        assert item.alias == 'Item "alias"'
+        assert item.json_alias == 'Item \\"alias\\"'
+        assert item.notes == 'Item notes'
+        assert item.status == 'unknown'
+
+        # Alias containing specific character (bis)
+        now = datetime.now()
+        parameters = {
+            'alias': "Item 'alias'",
+            'notes': 'Item notes',
+            'foo': 'bar', 'foo_int': 1,
+            'foo_date': '2016-04-01 10:58:13',
+            'now_date': now,
+            'dict_param': {
+                'param1': 1,
+                'param2': '2'
+            }
+        }
+        item = BackendElement(parameters, date_format='%Y-%m-%d %H:%M:%S')
+        print(item.__dict__)
+        assert item._id == 'item_5'  # New object
+        assert item.foo == 'bar'
+        assert item.foo_int == 1
+        assert item.foo_date == 1459508293
+        assert item.now_date == timegm(now.timetuple())
+        assert item.dict_param
+        print(item.dict_param)
+        assert item.dict_param['param1'] == 1
+        assert item.dict_param['param2'] == '2'
+
+        assert item.name == 'anonymous'
+        assert item.alias == "Item 'alias'"
+        assert item.json_alias == "Item \\'alias\\'"
+        assert item.notes == 'Item notes'
+        assert item.status == 'unknown'
+
     def test_users(self):
         """ Items - users"""
         print("--- test User")
@@ -674,6 +735,8 @@ class TestItems(unittest2.TestCase):
         assert item.is_administrator() == False
         assert item.is_anonymous() == False
         assert item.is_power() == True
+        assert item.can_change_dashboard() == False # Because default skill_level is 0
+        item.skill_level = 1
         assert item.can_change_dashboard() == True
         assert item.picture == '/static/images/user_default.png'
         assert item.token == 'token'
@@ -687,7 +750,8 @@ class TestItems(unittest2.TestCase):
             'user_name': 'test',
             'friendly_name': 'Friendly name',
             'password': 'test',
-            'is_admin': True
+            'is_admin': True,
+            'skill_level': 2
         })
         assert item._id == 'user_2'  # Not 0 because parameters are provided but auto generated because no _id in the parameters!
 
@@ -748,7 +812,8 @@ class TestItems(unittest2.TestCase):
         item = User({
             '_id': item._id,
             'alias': 'Aliased name (bis)',
-            'is_admin': True
+            'is_admin': True,
+            'skill_level': 2
         })
         assert item.alias == 'Aliased name (bis)'
         assert item.get_username() == 'test_priority'
@@ -796,16 +861,16 @@ class TestItems(unittest2.TestCase):
         assert len(Command.get_cache()) == 1
 
         print(item)
-        assert "%s" % item == "<command, id: command_0, name: anonymous, status: unknown>"
+        assert "%s" % item == "<command, id: command_0, name: Undefined command, status: unknown>"
         assert item._id == 'command_0'  # Because no _id in the parameters ...
         assert item._type == 'command'
-        assert item.name == 'anonymous'
+        assert item.name == 'Undefined command'
         assert item.status == 'unknown'
 
         assert item.status == 'unknown'
 
         print(item.get_html_state())
-        assert item.get_html_state() == '''<div class="item-state item_command " style="display: inline; font-size:0.9em;" data-item-id="%s" data-item-name="anonymous" data-item-type="command" data-item-state="" title=""><span class="fa-stack " ><i class="fa fa-circle fa-stack-2x item_command"></i><i class="fa fa-bolt fa-stack-1x fa-inverse"></i></span><span></span></div>''' % item.id
+        assert item.get_html_state() == '''<div class="item-state item_command " style="display: inline; font-size:0.9em;" data-item-id="%s" data-item-name="Undefined command" data-item-type="command" data-item-state="" title=""><span class="fa-stack " ><i class="fa fa-circle fa-stack-2x item_command"></i><i class="fa fa-bolt fa-stack-1x fa-inverse"></i></span><span></span></div>''' % item.id
 
     def test_hosts(self):
         """ Items - hosts """
@@ -856,6 +921,8 @@ class TestItems(unittest2.TestCase):
             'ls_last_check': now
         })
         print(item.__dict__)
+        print(now)
+        print(item.get_last_check(timestamp=True))
         assert item._id == 'host_1'
         assert item.get_last_check(timestamp=True) == timegm(now.timetuple())
 
@@ -873,3 +940,72 @@ class TestItems(unittest2.TestCase):
         print(item.updated)
         print(item.get_date(item.created))
         assert item.get_date(item.created) == '2016-08-12 11:50:33'
+
+    def test_services(self):
+        """ Items - services """
+        print("--- test Service")
+
+        # Global (Item) objects count
+        global_objects_count = BackendElement().get_count()
+        print(global_objects_count, "objects")
+        print("Global cache: ", BackendElement().get_cache())
+
+        # Base item
+        Service.clean_cache()
+        item = Service()
+        print(item.__dict__)
+        print(item)
+        assert item
+
+        # Specific (Session) objects count and cache
+        user_objects_count = item._count
+        print(user_objects_count, " Service objects")
+        print("Service cache: ", item._cache)
+
+        # Global objects count and cache did not changed
+        assert global_objects_count == BackendElement().get_count()
+        print("Global cache: ", BackendElement().get_cache())
+        assert len(BackendElement().get_cache()) == global_objects_count
+        # Only 1 Session object
+        assert item._count == 1
+        assert len(item._cache) == 1
+
+        print(item)
+        print(item.__dict__)
+        # status is None because there is no status_property defined
+        assert "%s" % item == "<service, id: service_0, name: anonymous, status: None>"
+        assert item._id == 'service_0'
+        assert item._type == 'service'
+        assert item.name == 'anonymous'
+        assert item.status is None
+
+        item = Service()
+        print(item.__dict__)
+        assert item._id == 'service_0'
+
+        # Host item with dates
+        now = datetime.now()
+        item = Service({
+            'name': 'test',
+            'ls_last_check': now
+        })
+        print(item.__dict__)
+        print(now)
+        print(item.get_last_check(timestamp=True))
+        assert item._id == 'service_1'
+        assert item.get_last_check(timestamp=True) == timegm(now.timetuple())
+
+        # Host item update
+        time.sleep(1)
+        now2 = datetime.now()
+        item = Service({
+            'name': 'test',
+            'last_check': now,
+            '_created': 1470995433,
+            '_updated': 1470995450,
+            'notes': 'Host notes'
+        })
+        print(item.created)
+        print(item.updated)
+        print(item.get_date(item.created))
+        assert item.get_date(item.created) == '2016-08-12 11:50:33'
