@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015:
+# Copyright (c) 2015-2017:
 #   Frederic Mohier, frederic.mohier@gmail.com
 #
 # This file is part of (WebUI).
@@ -30,14 +30,14 @@ import subprocess
 from nose.tools import *
 
 # Test environment variables
-os.environ['TEST_WEBUI'] = '1'
-os.environ['WEBUI_DEBUG'] = '1'
+os.environ['ALIGNAK_WEBUI_TEST'] = '1'
+os.environ['ALIGNAK_WEBUI_DEBUG'] = '1'
 os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'] = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'settings.cfg')
 print("Configuration file", os.environ['ALIGNAK_WEBUI_CONFIGURATION_FILE'])
 
 import alignak_webui.app
-from alignak_webui import webapp
-from alignak_webui.objects.datamanager import DataManager
+# from alignak_webui import webapp
+from alignak_webui.backend.datamanager import DataManager
 import alignak_webui.utils.datatable
 
 # from logging import getLogger, DEBUG, INFO
@@ -53,7 +53,7 @@ backend_address = "http://127.0.0.1:5000/"
 def setup_module(module):
     # Set test mode for applications backend
     os.environ['TEST_ALIGNAK_BACKEND'] = '1'
-    os.environ['ALIGNAK_BACKEND_MONGO_DBNAME'] = 'alignak-backend-test'
+    os.environ['ALIGNAK_BACKEND_MONGO_DBNAME'] = 'alignak-webui-tests'
 
     # Delete used mongo DBs
     exit_code = subprocess.call(
@@ -79,7 +79,7 @@ def setup_module(module):
 
     print("Feeding Alignak backend... %s" % test_dir)
     exit_code = subprocess.call(
-        shlex.split('alignak-backend-import --delete %s/cfg/default/_main.cfg' % test_dir),
+        shlex.split('alignak-backend-import --delete %s/cfg/alignak-demo/alignak-backend-import.cfg' % test_dir),
         stdout=fnull
     )
     assert exit_code == 0
@@ -101,9 +101,7 @@ class TestsExternal(unittest2.TestCase):
         print("setting up ...")
 
         # Test application
-        self.app = TestApp(
-            webapp
-        )
+        self.app = TestApp(alignak_webui.app.session_app)
 
     def test_refused(self):
         """ External - refused"""
@@ -172,7 +170,7 @@ class TestsExternal(unittest2.TestCase):
         response.mustcontain('<div><h1>Unknown required widget: unknown.</h1><p>The required widget is not available.</p></div>')
 
     def test_allowed_widgets(self):
-        """ External - allowed widgets"""
+        """External - allowed widgets"""
         print('allowed widgets external access')
 
         # Allowed - default widgets parameters: widget_id and widget_template
@@ -199,8 +197,11 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="wd_panel_hosts_table" class="panel panel-default alignak_webui_widget embedded">',
-            '<small>Graphite on VM</small>',
-            '<small>check_host_alive</small>'
+            '<thead><tr>',
+            '<th>Host name</th>',
+            '<th>Business impact</th>',
+            '<th>Check command</th>',
+            '<td title="Glpi / Alignak">'
         )
 
         # Allowed - default widgets parameters: widget_id
@@ -212,8 +213,11 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="wd_panel_hosts_table" class="panel panel-default alignak_webui_widget embedded">',
-            'Graphite on VM</small>',
-            'check_host_alive</small>'
+            '<thead><tr>',
+            '<th>Host name</th>',
+            '<th>Business impact</th>',
+            '<th>Check command</th>',
+            '<td title="Glpi / Alignak">'
         )
 
         # Allowed - default widgets parameters: widget_id
@@ -226,8 +230,11 @@ class TestsExternal(unittest2.TestCase):
         response.mustcontain(
             '<div id="wd_panel_hosts_table" class="panel panel-default alignak_webui_widget embedded">',
             '<a href="http://test/host/',
-            'Graphite on VM</a></small>',
-            'check_host_alive</a></small>'
+            '<thead><tr>',
+            '<th>Host name</th>',
+            '<th>Business impact</th>',
+            '<th>Check command</th>',
+            '<td title="Glpi / Alignak">'
         )
 
         # Allowed - default widgets parameters: widget_id
@@ -243,7 +250,7 @@ class TestsExternal(unittest2.TestCase):
         )
 
     def test_allowed_tables(self):
-        """ External - allowed tables"""
+        """External - allowed tables"""
         print('allowed tables external access')
 
         # Allowed - default table parameters: none
@@ -272,9 +279,12 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="hosts_table" class="alignak_webui_table embedded">',
-            '<th data-name="name" data-type="string">Host name</th>',
-            '<th data-name="tags" data-type="list">Tags</th>',
-            '<th data-name="alias" data-type="string">Host alias</th>'
+            '<th data-name="name" data-type="string"',
+            '<th data-name="ls_state" data-type="string"',
+            '<th data-name="overall_status" data-type="string"',
+            '<th data-name="tags" data-type="list"',
+            '<th data-name="address" data-type="string"',
+            '<th data-name="business_impact" data-type="integer"'
         )
 
         # Allowed - default table parameters: none
@@ -287,9 +297,12 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="hosts_table" class="alignak_webui_table embedded">',
-            '<th data-name="name" data-type="string">Host name</th>',
-            '<th data-name="tags" data-type="list">Tags</th>',
-            '<th data-name="alias" data-type="string">Host alias</th>'
+            '<th data-name="name" data-type="string"',
+            '<th data-name="ls_state" data-type="string"',
+            '<th data-name="overall_status" data-type="string"',
+            '<th data-name="tags" data-type="list"',
+            '<th data-name="address" data-type="string"',
+            '<th data-name="business_impact" data-type="integer"'
         )
 
         # Allowed - default table parameters: none
@@ -302,14 +315,17 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="hosts_table" class="alignak_webui_table embedded">',
-            '<th data-name="name" data-type="string">Host name</th>',
-            '<th data-name="tags" data-type="list">Tags</th>',
-            '<th data-name="alias" data-type="string">Host alias</th>',
+            '<th data-name="name" data-type="string"',
+            '<th data-name="ls_state" data-type="string"',
+            '<th data-name="overall_status" data-type="string"',
+            '<th data-name="tags" data-type="list"',
+            '<th data-name="address" data-type="string"',
+            '<th data-name="business_impact" data-type="integer"',
             '"url": "http://localhost:80/external/table/hosts_table/hosts/table_data",'
         )
 
     def test_host_widgets(self):
-        """ External - host widgets"""
+        """External - host widgets"""
         print('allowed host widgets external access')
 
         # Log in to get Data manager in the session
@@ -321,19 +337,16 @@ class TestsExternal(unittest2.TestCase):
         # Redirected twice: /login -> / -> /dashboard !
         redirected_response = response.follow()
         redirected_response = redirected_response.follow()
-        redirected_response.mustcontain('<div id="dashboard">')
+        redirected_response.mustcontain('<div id="livestate">')
 
         session = redirected_response.request.environ['beaker.session']
         assert 'current_user' in session and session['current_user']
         assert session['current_user'].get_username() == 'admin'
 
-        datamgr = DataManager(
-            session=session,
-            backend_endpoint='http://127.0.0.1:5000'
-        )
+        datamgr = DataManager(alignak_webui.app.app, session=session)
 
         # Get host in the backend
-        host = datamgr.get_host({'where': {'name': 'webui'}})
+        host = datamgr.get_host({'where': {'name': 'alignak_glpi'}})
 
         # Get external host widget - no widget identifier
         self.app.authorization = ('Basic', ('admin', 'admin'))
@@ -351,7 +364,36 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain('<div><h1>Unknown required widget: unknown.</h1><p>The required widget is not available.</p></div>')
 
+        # Host view
+        # ---
+        # Get external host widget
+        self.app.authorization = ('Basic', ('admin', 'admin'))
+        response = self.app.get(
+            '/external/host/%s/view?page' % host.id
+        )
+        response.mustcontain(
+            '<!DOCTYPE html>',
+            '<html lang="en">',
+            '<body>',
+            '<section>',
+            '<div id="wd_panel_view" class="panel panel-default alignak_webui_widget embedded">',
+            '<!-- Hosts view widget -->',
+            '</section>',
+            '</body>'
+        )
+
+        # Get external host widget, no page parameter
+        self.app.authorization = ('Basic', ('admin', 'admin'))
+        response = self.app.get(
+            '/external/host/%s/view' % host.id
+        )
+        response.mustcontain(
+            '<div id="wd_panel_view" class="panel panel-default alignak_webui_widget embedded">',
+            '<!-- Hosts view widget -->',
+        )
+
         # Host information
+        # ---
         # Get external host widget
         self.app.authorization = ('Basic', ('admin', 'admin'))
         response = self.app.get(
@@ -379,6 +421,7 @@ class TestsExternal(unittest2.TestCase):
         )
 
         # Host configuration
+        # ---
         # Get external host widget
         self.app.authorization = ('Basic', ('admin', 'admin'))
         response = self.app.get(
@@ -406,6 +449,7 @@ class TestsExternal(unittest2.TestCase):
         )
 
         # Host metrics
+        # ---
         # Get external host widget
         self.app.authorization = ('Basic', ('admin', 'admin'))
         response = self.app.get(
@@ -433,6 +477,7 @@ class TestsExternal(unittest2.TestCase):
         )
 
         # Host timeline
+        # ---
         # Get external host widget
         self.app.authorization = ('Basic', ('admin', 'admin'))
         response = self.app.get(
@@ -444,9 +489,12 @@ class TestsExternal(unittest2.TestCase):
             '<body>',
             '<section>',
             '<div id="wd_panel_timeline" class="panel panel-default alignak_webui_widget embedded">',
-            '<!-- Hosts timeline widget -->',
+            '<!-- Host timeline widget -->',
             '</section>',
-            '</body>'
+            '</body>',
+            '<div class="alert alert-info">',
+            '<p class="font-blue">No available history events.</p>',
+            '</div>'
         )
 
         # Get external host widget, no page parameter
@@ -456,10 +504,11 @@ class TestsExternal(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="wd_panel_timeline" class="panel panel-default alignak_webui_widget embedded">',
-            '<!-- Hosts timeline widget -->',
+            '<!-- Host timeline widget -->',
         )
 
         # Host services
+        # ---
         # Get external host widget
         self.app.authorization = ('Basic', ('admin', 'admin'))
         response = self.app.get(
@@ -486,37 +535,36 @@ class TestsExternal(unittest2.TestCase):
             '<!-- Hosts services widget -->',
         )
 
-        # Host history
-        # Get external host widget
-        self.app.authorization = ('Basic', ('admin', 'admin'))
-        response = self.app.get(
-            '/external/host/%s/history?page' % host.id
-        )
-        response.mustcontain(
-            '<!DOCTYPE html>',
-            '<html lang="en">',
-            '<body>',
-            '<section>',
-            '<div id="wd_panel_history" class="panel panel-default alignak_webui_widget embedded">',
-            '<!-- Hosts history widget -->',
-            '</section>',
-            '</body>'
-        )
+        # Temporarily disabled
+        # # Host history
+        # # Get external host widget
+        # self.app.authorization = ('Basic', ('admin', 'admin'))
+        # response = self.app.get(
+        #     '/external/host/%s/history?page' % host.id
+        # )
+        # response.mustcontain(
+        #     '<!DOCTYPE html>',
+        #     '<html lang="en">',
+        #     '<body>',
+        #     '<section>',
+        #     '<div id="wd_panel_history" class="panel panel-default alignak_webui_widget embedded">',
+        #     '<!-- Hosts history widget -->',
+        #     '</section>',
+        #     '</body>'
+        # )
+        #
+        # # Get external host widget, no page parameter
+        # self.app.authorization = ('Basic', ('admin', 'admin'))
+        # response = self.app.get(
+        #     '/external/host/%s/history' % host.id
+        # )
+        # response.mustcontain(
+        #     '<div id="wd_panel_history" class="panel panel-default alignak_webui_widget embedded">',
+        #     '<!-- Hosts history widget -->',
+        # )
 
-        # Get external host widget, no page parameter
-        self.app.authorization = ('Basic', ('admin', 'admin'))
-        response = self.app.get(
-            '/external/host/%s/history' % host.id
-        )
-        response.mustcontain(
-            '<div id="wd_panel_history" class="panel panel-default alignak_webui_widget embedded">',
-            '<!-- Hosts history widget -->',
-        )
-
-    @unittest2.skip("Do not understand ... I suspect Travis "
-                    "to not contain the same data in the backend!")
     def test_service_widgets(self):
-        """ External - service widgets"""
+        """External - service widgets"""
         print('allowed service widgets external access')
 
         # Log in to get Data manager in the session
@@ -528,23 +576,23 @@ class TestsExternal(unittest2.TestCase):
         # Redirected twice: /login -> / -> /dashboard !
         redirected_response = response.follow()
         redirected_response = redirected_response.follow()
-        redirected_response.mustcontain('<div id="dashboard">')
+        redirected_response.mustcontain('<div id="livestate">')
 
         session = redirected_response.request.environ['beaker.session']
         assert 'current_user' in session and session['current_user']
         assert session['current_user'].get_username() == 'admin'
 
-        datamgr = DataManager(
-            session=session,
-            backend_endpoint='http://127.0.0.1:5000'
-        )
+        datamgr = DataManager(alignak_webui.app.app, session=session)
 
         # Get host and service in the backend
-        host = datamgr.get_host({'where': {'name': 'webui'}})
+        host = datamgr.get_host({'where': {'name': 'KNM-Shinken'}})
         print("Host: %s" % host)
-        service = datamgr.get_service({'where': {'name': 'Load', 'host': host.id}})
+        services = datamgr.get_host_services(host)
+        print("Services: %s" % services)
+        # service = datamgr.get_service({'where': {'name': 'http', 'host': host.id}})
+        service = services[0]
         print("Service: %s" % service)
-        assert False
+        # assert False
 
         # Get external service widget - no widget identifier
         self.app.authorization = ('Basic', ('admin', 'admin'))
@@ -568,7 +616,6 @@ class TestsExternal(unittest2.TestCase):
         response = self.app.get(
             '/external/service/%s/information?page' % service.id
         )
-        print(response)
         response.mustcontain(
             '<!DOCTYPE html>',
             '<html lang="en">',
@@ -617,6 +664,36 @@ class TestsExternal(unittest2.TestCase):
             '<!-- Service configuration widget -->',
         )
 
+        # Service timeline
+        # Get external service widget
+        self.app.authorization = ('Basic', ('admin', 'admin'))
+        response = self.app.get(
+            '/external/service/%s/timeline?page' % service.id
+        )
+        response.mustcontain(
+            '<!DOCTYPE html>',
+            '<html lang="en">',
+            '<body>',
+            '<section>',
+            '<div id="wd_panel_timeline" class="panel panel-default alignak_webui_widget embedded">',
+            '<!-- Service timeline widget -->',
+            '</section>',
+            '</body>',
+            '<div class="alert alert-info">',
+            '<p class="font-blue">No available history events.</p>',
+            '</div>'
+        )
+
+        # Get external service widget, no page parameter
+        self.app.authorization = ('Basic', ('admin', 'admin'))
+        response = self.app.get(
+            '/external/service/%s/timeline' % service.id
+        )
+        response.mustcontain(
+            '<div id="wd_panel_timeline" class="panel panel-default alignak_webui_widget embedded">',
+            '<!-- Service timeline widget -->',
+        )
+
         # service metrics
         # Get external service widget
         self.app.authorization = ('Basic', ('admin', 'admin'))
@@ -645,7 +722,7 @@ class TestsExternal(unittest2.TestCase):
         )
 
     def test_user_widgets(self):
-        """ External - user widgets"""
+        """External - user widgets"""
         print('allowed user widgets external access')
 
         # Log in to get Data manager in the session
@@ -657,16 +734,13 @@ class TestsExternal(unittest2.TestCase):
         # Redirected twice: /login -> / -> /dashboard !
         redirected_response = response.follow()
         redirected_response = redirected_response.follow()
-        redirected_response.mustcontain('<div id="dashboard">')
+        redirected_response.mustcontain('<div id="livestate">')
 
         session = redirected_response.request.environ['beaker.session']
         assert 'current_user' in session and session['current_user']
         assert session['current_user'].get_username() == 'admin'
 
-        datamgr = DataManager(
-            session=session,
-            backend_endpoint='http://127.0.0.1:5000'
-        )
+        datamgr = DataManager(alignak_webui.app.app, session=session)
 
         # Get user in the backend
         user = datamgr.get_user({'where': {'name': 'imported_admin'}})
@@ -724,12 +798,10 @@ class TestAllWidgets(unittest2.TestCase):
         print("setting up ...")
 
         # Test application
-        self.app = TestApp(
-            webapp
-        )
+        self.app = TestApp(alignak_webui.app.session_app)
 
     def test_widgets(self):
-        """ External - allowed widgets"""
+        """External - get all allowed widgets"""
         print('allowed widgets')
 
         # Hosts table
@@ -739,8 +811,11 @@ class TestAllWidgets(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="wd_panel_hosts_table" class="panel panel-default alignak_webui_widget embedded">',
-            '<small>Graphite on VM</small>',
-            '<small>check_host_alive</small>'
+            '<thead><tr>',
+            '<th>Host name</th>',
+            '<th>Business impact</th>',
+            '<th>Check command</th>',
+            '<td title="Glpi / Alignak">'
         )
 
         # Hosts graph
@@ -760,7 +835,10 @@ class TestAllWidgets(unittest2.TestCase):
         )
         response.mustcontain(
             '<div id="wd_panel_services_table" class="panel panel-default alignak_webui_widget embedded">',
-            '<small>BigProcesses</small>'
+            '<th>Host</th>',
+            '<th>Service</th>',
+            '<th>Business impact</th>',
+            '<th>Check command</th>'
         )
 
         # Services graph
@@ -773,6 +851,16 @@ class TestAllWidgets(unittest2.TestCase):
             '<div id="pc_services_services_chart">'
         )
 
+        # Livestate table
+        self.app.authorization = ('Basic', ('admin', 'admin'))
+        response = self.app.get(
+            '/external/widget/livestate?widget_id=livestate'
+        )
+        response.mustcontain(
+            '<div id="wd_panel_livestate" class="panel panel-default alignak_webui_widget embedded">',
+            '<div id="livestate-bi--1">'
+        )
+
 
 class TestExternalFiles(unittest2.TestCase):
 
@@ -780,12 +868,10 @@ class TestExternalFiles(unittest2.TestCase):
         print("setting up ...")
 
         # Test application
-        self.app = TestApp(
-            webapp
-        )
+        self.app = TestApp(alignak_webui.app.session_app)
 
     def test_request_unknown_files(self):
-        """ External - request list of js files - unknown files"""
+        """External - request list of js files - unknown files"""
         print('Request list of js files')
 
         # Allowed - default widgets parameters: widget_id and widget_template
@@ -801,7 +887,7 @@ class TestExternalFiles(unittest2.TestCase):
         assert response.json['message']
 
     def test_request_js_files(self):
-        """ External - request list of js files"""
+        """External - request list of js files"""
         print('Request list of js files')
 
         # Allowed - default widgets parameters: widget_id and widget_template
@@ -826,6 +912,7 @@ class TestExternalFiles(unittest2.TestCase):
             "/static/js/typeahead.bundle.min.js",
             "/static/js/screenfull.js",
             "/static/js/alertify.min.js",
+            "/static/js/BootSideMenu.js",
             "/static/js/selectize.min.js",
             "/static/js/Chart.min.js",
             "/static/js/jstree.min.js",
@@ -837,28 +924,28 @@ class TestExternalFiles(unittest2.TestCase):
         assert reference == response.json['files']
 
     def test_request_css_files(self):
-        """ External - request list of js files - CSS files"""
+        """External - request list of js files - CSS files"""
         print('Request list of css files')
 
         # Allowed - default widgets parameters: widget_id and widget_template
         # Add parameter page to get a whole page: js, css, ...
         self.app.authorization = ('Basic', ('admin', 'admin'))
-        response = self.app.get(
-            '/external/files/css_list'
-        )
+        response = self.app.get('/external/files/css_list')
         print(response)
         assert response.json['status'] == "ok"
         assert "files" in response.json
         assert response.json['files']
 
-        reference =  [
+        reference = [
             "/static/css/bootstrap.min.css",
             "/static/css/font-awesome.min.css",
             "/static/css/typeahead.css",
             "/static/css/daterangepicker.css",
-            "/static/css/alertify.min.css",
-            "/static/css/alertify.bootstrap.min.css",
+            "/static/css/alertify/alertify.min.css",
+            "/static/css/alertify/bootstrap.min.css",
+            "/static/css/BootSideMenu.css",
             "/static/css/timeline.css",
+            "/static/css/selectize.bootstrap3.css",
             "/static/css/font-roboto.css",
             "/static/css/material-icons.css",
             "/static/css/material/bootstrap-material-design.min.css",
